pub struct RowIDWithConfigState {
pub char_list: String,
pub randomness_length: usize,
}Expand description
This struct contains the state of the RowIDWithConfig struct.
Fields
char_list: StringThe list of characters used in the current function.
randomness_length: usizeThe length of randomness used in the current function.